---
title: KG이니시스 부가세 설정방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 부가세
seo:
  title: KG이니시스 부가세 설정방법
  description: >-
    KG이니시스는 계약 시 상점아이디(MID) 별로 부가세 설정이 가능합니다. 과세, 면세, 복합과세 설정된 MID로 결제하시는 경우
    처리되는 결과에 대해 확인해보세요.
  keywords:
    - 일반결제
tags:
  - KG이니시스
  - 부가세
pgCompanies:
  - KG이니시스
searchTags:
  - 과세
  - 비과세
  - 면세
  - 부가세
  - 부과세 파라미터
  - 부가세설정
  - KG이니시스 부가세
  - 이니시스 부가세
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="KG이니시스는 계약 시 상점아이디(MID) 별로 부가세 설정을 할 수 있습니다. 부가세 설정에 따른 적용기준을 안내드립니다." />

#### **1. 상점아이디(MID)를 ‘과세’로 설정 > 거래 일괄 과세**

과세로 설정된 MID로 결제를 하는 경우 지정하시는 파라미터(tax\_free)와 관계없이 KG이니시스 내부적으로 **일괄 과세**로 처리합니다.

#### **2. 상점아이디(MID)를 ‘면세’로 설정 > 거래 일괄 면세**

면세로 설정된 MID로 결제를 하는 경우 지정하시는 파라미터(tax\_free)와 관계없이 KG이니시스 내부적으로 **일괄 면세**로 처리합니다.

#### **3. 상점아이디(MID)를 ‘복합과세’로 설정 > 파라미터 값에 따라 처리**

복합과세로 설정된 MID로 결제를 하는 경우, 결제 요청시마다 지정하시는 파라미터(tax\_free)에 따라 면세금액이 결정됩니다. 면세상품과 과세 상품이 함께 존재하고 두 상품이 한 번에 결제가 발생되어야 하는 경우에 이와 같이 구분하실 수 있습니다.

참고로 이 경우 취소 시에도 동일하게 취소 금액 중 면세금액에 해당되는 금액을 반드시 지정해 주셔야 합니다. (tax\_free를 0으로 지정했을 경우, 취소 시에도 tax\_free를 0으로 지정해야 함) 만약 tax\_free 파라미터가 지정되지 않을 경우, 거래건 전액 ‘면세’로 반영됩니다.

<Callout content="MID 설정이 기존에 과세로 되어 있었다면 중도에 복합과세로 중도 변경 시 이전 거래건들까지 일괄 복합과세로 변경됩니다.  기존 거래는 과세를 유지하고 싶으시다면, 복합과세용에 맞는 MID를 추가로 발급받아주세요.
" title="유의사항" icon="❗" />
